@@ -1,7 +1,5 @@
 /******************************************************************************
- * mod_uploader / FileWriter.h
- ******************************************************************************
- * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
+ * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
  * All rights reserved.
  *
@@ -24,80 +22,91 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: FileWriter.h 1003 2006-03-14 13:52:47Z svn $
+ * $Id: FileWriter.h 2035 2006-11-23 16:14:21Z svn $
  *****************************************************************************/
 
 #ifndef FILE_WRITER_H
 #define FILE_WRITER_H
 
-#include "apr_file_io.h"
+#include "Environment.h"
 
 #include <cstdlib>
 
-#ifdef HAVE_CONFIG_H
-#include "mod_uploader_config.h"
-#endif
+#include "apr_file_io.h"
+
+#include "Uncopyable.h"
 
 using namespace std;
+
+class File;
+
 /**
- * @brief եإǡ񤭽Ф饹
+ * @brief ファイルへデータを書き出すクラス．
  */
-class FileWriter
+class FileWriter: public Uncopyable
 {
 public:
     /**
-     * 󥹥ȥ饯
+     * コンストラクタ．
      *
-     * @param[in] pool ס
-     * @param[in] fd եϥɥ
+     * @param[in] pool プール
+     * @param[in] file ファイルハンドラ
      */
-    FileWriter(apr_pool_t *pool, apr_file_t *fd);
+    FileWriter(apr_pool_t *pool, apr_file_t *file);
     /**
-     * եؤν񤭽ФԤޤ
+     * ファイルへの書き出しを行います．
+     * 実際の書き込み処理は write_impl に委譲します．
      *
-     * @param[in] buf 񤭽Фǡ
-     * @param[in] size 񤭽Ф
-     * @exception const char * 񤭽Ф˼Ԥ
+     * @param[in] buffer 書き出すデータ
+     * @param[in] size 書き出すサイズ
+     * @exception const char * 書き出しに失敗した場合
      */
-    virtual void write(const void *buf, apr_size_t size) = 0;
+    void write(const void *buffer, apr_size_t size)
+    {
+        if (size == 0) {
+            return;
+        }
+
+        write_impl(buffer, size);
+        write_size_ += size;
+    }
     /**
-     * եĤޤ
+     * ファイルを閉じます．
      *
-     * @exception const char * ĤΤ˼Ԥ
+     * @exception const char * 閉じるのに失敗した場合
      */
+    apr_size_t get_write_size() const
+    {
+        return write_size_;
+    };
     virtual void close();
     /**
-     * ǥȥ饯
+     * デストラクタ．
      *
-     * եĤޤ
+     * ファイルを閉じます．
      */
     virtual ~FileWriter();
 protected:
-    apr_pool_t *get_pool()
-    {
-        return pool_;
-    }
+    /**
+     * ファイルへの書き出しを実際に行います．
+     *
+     * @param[in] buffer 書き出すデータ
+     * @param[in] size 書き出すサイズ
+     * @exception const char * 書き出しに失敗した場合
+     */
+    virtual void write_impl(const void *buffer, apr_size_t size) = 0;
 
-    apr_file_t *get_fd()
-    {
-        return fd_;
-    }
-
-private:
-    FileWriter(const FileWriter &);
-    FileWriter &operator=(const FileWriter &);
-
-    /** ס */
+    /** プール */
     apr_pool_t *pool_;
-    /** եϥɥ */
-    apr_file_t *fd_;
-    /** ˥ե뤬 close 줿ɤ */
-    bool is_closed_;
+    /** ファイルハンドラ */
+    File *file_;
+    /** 書き込んだサイズ */
+    apr_size_t write_size_;
 };
 
 #endif
 
 // Local Variables:
 // mode: c++
-// buffer-file-coding-system: euc-japan-dos
+// coding: utf-8-dos
 // End:
